# coding: utf-8
#
# Copyright (c) 2013-2023 NIBIO.
#
# This file is part of VIPSWeb 
# (see https://gitlab.nibio.no/VIPS/VIPSWeb).
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
#

# Author: Tor-Einar Skog <tor-einar.skog@nibio.no>

from datetime import datetime
from django.utils.dateparse import parse_datetime

def get_unix_timestamp(datetime_object):
    """GET Unix timestamp (milliseconds since 1970-01-01 UTC) from datetime object"""
    # The strftime("%s") is UNIX implementation dependent
    return int(datetime_object.strftime("%s")) * 1000
    #return (datetime_object - datetime(1970,1,1)).total_seconds() * 1000

def parse_json_timestamp(timestamp_str):
    """ Either it's a UNIX timestamp or an ISO datetime string """
    try:
        return datetime.fromtimestamp(timestamp_str/1000)
    except TypeError:
        return parse_datetime(timestamp_str)